@@ -17,11 +17,10 @@
 # Last check: May 21, 2003 at 11:55 AM
 #
 
-CREATE TABLE IF NOT EXISTS `Corpus` (
+CREATE TABLE `Corpus` (
   `UserName` varchar(175) NOT NULL default '',
   `Token` varchar(128) binary NOT NULL default '',
-  `Score` float unsigned NOT NULL default '0',
-  `count` bigint(20) unsigned NOT NULL default '0',
+  `Score` float NOT NULL default '0',
   PRIMARY KEY  (`UserName`,`Token`)
 ) TYPE=MyISAM PACK_KEYS=1;
 # --------------------------------------------------------
@@ -50,11 +49,10 @@ CREATE TABLE `Messages` (
 # Last update: May 21, 2003 at 03:21 PM
 #
 
-CREATE TABLE IF NOT EXISTS `ScoreCache` (
+CREATE TABLE `ScoreCache` (
   `UserName` varchar(175) NOT NULL default '',
   `MessageID` varchar(32) NOT NULL default '',
-  `Score` float unsigned NOT NULL default '0',
-  `Tokens` bigint(20) unsigned NOT NULL default '0',
+  `Score` float NOT NULL default '0',
   `Added` timestamp(14) NOT NULL,
   PRIMARY KEY  (`UserName`,`MessageID`)
 ) TYPE=MyISAM;
@@ -71,7 +69,7 @@ CREATE TABLE IF NOT EXISTS `ScoreCache` (
 CREATE TABLE `nonspamOccurences` (
   `UserName` varchar(175) NOT NULL default '',
   `Token` varchar(128) binary NOT NULL default '',
-  `Frequency` bigint(20) unsigned NOT NULL default '0',
+  `Frequency` int(10) unsigned NOT NULL default '0',
   `LastUpdate` timestamp(14) NOT NULL,
   PRIMARY KEY  (`UserName`,`Token`)
 ) TYPE=MyISAM;
@@ -88,7 +86,7 @@ CREATE TABLE `nonspamOccurences` (
 CREATE TABLE `spamOccurences` (
   `UserName` varchar(175) NOT NULL default '',
   `Token` varchar(128) binary NOT NULL default '',
-  `Frequency` bigint(20) unsigned NOT NULL default '0',
+  `Frequency` int(10) unsigned NOT NULL default '0',
   `LastUpdate` timestamp(14) NOT NULL,
   PRIMARY KEY  (`UserName`,`Token`)
 ) TYPE=MyISAM;
@@ -131,8 +129,8 @@ CREATE TABLE `stats` (
 
 CREATE TABLE `users` (
   `UserName` varchar(175) NOT NULL default '',
-  `nonspamCount` bigint(20) unsigned NOT NULL default '0',
-  `spamCount` bigint(20) unsigned NOT NULL default '0',
+  `nonspamCount` int(10) unsigned NOT NULL default '0',
+  `spamCount` int(10) unsigned NOT NULL default '0',
   `LastRebuild` datetime NOT NULL default '0000-00-00 00:00:00',
   `LastAdd` datetime NOT NULL default '0000-00-00 00:00:00',
   PRIMARY KEY  (`UserName`)
