@@ -11,21 +11,16 @@ function bayesspam_filter($args) {
    } else {
       bayesspam_filters($GLOBALS['imapConnection'], 1);
    }
+   return 1;
 }
 
-function bayesspam_filters(&$imap_stream, $use_mailbox=0) {
-   $version_array = split('\.', $GLOBALS['version']);
-
-   $new_spam_occurences = array();
-   $new_nonspam_occurences = array();
+function bayesspam_filters($imap_stream, $use_mailbox=0) {
    $spam_stats = 0;
    $ham_stats = 0;
    $unsure_stats = 0;
    $total_messages = 0;
-
    $run_folders = array();
    $boxes = sqimap_mailbox_list($imap_stream);
-   $sid = sqimap_session_id();
 
    foreach ($boxes as $box) {
       if ($GLOBALS['bayesspam_inboxonly'] != 1 || ($GLOBALS['bayesspam_inboxonly'] == 1 && preg_match("/^INBOX$/", $box['unformatted-dm']))) {
