@@ -18,6 +18,11 @@ sqimap_logout($imapConnection);
 
 displayPageHeader($GLOBALS['color'], 'None');
 
+bindtextdomain('bayesspam', SM_PATH . 'plugins/bayesspam/locale');
+textdomain('bayesspam');
+
+$version_array = split('\.', $GLOBALS['version']);
+
 if (!isset($_REQUEST)) {
    $_REQUEST = array_merge($HTTP_GET_VARS,$HTTP_POST_VARS);
 }   
@@ -48,6 +53,10 @@ elseif ($_REQUEST['action'] == 'refreshrebuild')
    setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_rebuild_on_refresh', 1);
 elseif ($_REQUEST['action'] == 'norefreshrebuild')
    setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_rebuild_on_refresh', '');
+elseif ($_REQUEST['action'] == 'showspambuttons')
+   setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_show_spam_buttons', 1);
+elseif ($_REQUEST['action'] == 'noshowspambuttons')
+   setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_show_spam_buttons', '');
 elseif ($_REQUEST['action'] == 'showprob')
    setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_show_prob', 1);
 elseif ($_REQUEST['action'] == 'noshowprob')
@@ -64,11 +73,19 @@ elseif ($_REQUEST['action'] == 'folder' && isset($_REQUEST['folder']))
    setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_folder', $_REQUEST['folder']);
 elseif ($_REQUEST['action'] == 'uncertainfolder' && isset($_REQUEST['uncertainfolder']))
    setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_uncertain_folder', $_REQUEST['uncertainfolder']);
-elseif ($_REQUEST['action'] == 'set_scan_size' && isset($_REQUEST['scan_size'])) {
-   if ($_REQUEST['scan_size'] > $GLOBALS['bayes_max_size']) {
+elseif ($_REQUEST['action'] == 'set_prune' && isset($_REQUEST['prune_days'])) {
+   if ((int) $_REQUEST['prune_days'] > 365) {
+      $_REQUEST['prune_days'] = 365;
+   }
+   if ((int) $_REQUEST['prune_days'] < 0 || $_REQUEST['prune_days'] == '') {
+      $_REQUEST['prune_days'] = 0;
+   }
+   setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_prune_threshold', $_REQUEST['prune_days']);
+} elseif ($_REQUEST['action'] == 'set_scan_size' && isset($_REQUEST['scan_size'])) {
+   if ((int) $_REQUEST['scan_size'] > $GLOBALS['bayes_max_size']) {
       $_REQUEST['scan_size'] = $GLOBALS['bayes_max_size'];
    }
-   setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_scan_size', $_REQUEST['scan_size']);
+   setPref($GLOBALS['data_dir'], $GLOBALS['username'], 'bayesspam_scan_size', (int) $_REQUEST['scan_size']);
 } elseif ($_REQUEST['action'] == 'ignore_add' && isset($_REQUEST['ignore_add'])) {
    $GLOBALS['bayesspam_ignore_folders'][] = $_REQUEST['ignore_add'];
    array_unique($GLOBALS['bayesspam_ignore_folders']);
@@ -137,8 +154,21 @@ if (!DB::isError($res)) {
    </tr>
 </table>
 <br>
-
 <table align=center>
+   <?php if ($version_array[0] == 1 && $version_array[1] == 5) { ?>
+   <tr>
+      <td align=right>
+         <?php echo _("Spam/Nonspam Message List Buttons are"); ?>:
+      </td>
+      <td>
+         <?php if ($GLOBALS['bayesspam_show_spam_buttons']) { ?>
+            <font color=darkgreen><?php echo _("Enabled"); ?></font> (<a href="options.php?action=noshowspambuttons"><?php echo _("Disable it"); ?></a>)
+         <?php } else { ?>
+            <font color=red><?php echo _("Disabled"); ?></font> (<a href="options.php?action=showspambuttons"><?php echo _("Enable it"); ?></a>)
+         <?php } ?>
+      </td>
+   </tr>
+   <?php } ?>
    <tr>
       <td align=right>
          <?php echo _("BayesSpam Probability Display is"); ?>:
@@ -250,19 +280,36 @@ if (!DB::isError($res)) {
       </td>
    </tr>
    <tr><td>&nbsp;</td></tr>
+   <?php $bl = strlen($GLOBALS['bayes_max_size']); ?>
+   <?php if ($GLOBALS['bayes_user_scan_size'] == TRUE) { ?>
    <tr>
       <td align=right>
          <?php echo _("Bytes of message to scan"); ?>:<br>
-         <font size=-1><?php echo _("Maximum"); ?>: <?php echo $GLOBALS['bayes_max_size']; ?></font>
+         <?php echo _("Maximum"); ?>: <?php echo $GLOBALS['bayes_max_size']; ?>
       </td>
       <form method=post action=options.php>
          <td>
-            <input type=text name=scan_size value="<?php echo $GLOBALS['bayesspam_scan_size']; ?>">
+            <input type=text name=scan_size size=<?php echo $bl+2; ?> maxlength=<?php echo $bl; ?> value="<?php echo $GLOBALS['bayesspam_scan_size']; ?>">
             <input type=hidden name=action value="set_scan_size"></td><td>
             <input type=submit value="<?php echo _("Save"); ?>">
          </td>
       </form>
    </tr>
+   <?php } ?>
+   <tr><td>&nbsp;</td></tr>
+   <tr>
+      <td align=right>
+         <?php echo _("Delete Spam older than X Days"); ?>:<br>
+         (<?php echo _("0 to disable"); ?>)
+      </td>
+      <form method=post action=options.php>
+         <td>
+            <input type=text name=prune_days size=<?php echo $bl+2; ?> maxlength=3 value="<?php echo $GLOBALS['bayesspam_prune_threshold']; ?>">
+            <input type=hidden name=action value="set_prune"></td><td>
+            <input type=submit value="<?php echo _("Save"); ?>">
+         </td>
+      </form>
+   </tr>
    <tr><td>&nbsp;</td></tr>
    <tr>
       <td align=right>
@@ -344,7 +391,7 @@ if (!DB::isError($res)) {
                <select name=ignore_add>
                   <?php
                      for ($i = 0; $i < count($boxes); $i++) {
-                        if (!(in_array('noselect', $boxes[$i]['flags'])) && $boxes[$i]['unformatted'] != 'INBOX.Trash' && $boxes[$i]['unformatted'] != $GLOBALS['bayesspam_folder'] && !(in_array($boxes[$i]['unformatted'],$GLOBALS['bayesspam_ignore_folders']))) {
+                        if (!(in_array('noselect', $boxes[$i]['flags'])) && $boxes[$i]['unformatted'] != $GLOBALS['trash_folder'] && $boxes[$i]['unformatted'] != $GLOBALS['bayesspam_folder'] && !(in_array($boxes[$i]['unformatted'],$GLOBALS['bayesspam_ignore_folders']))) {
                            $box = $boxes[$i]['unformatted'];
                            $box2 = str_replace(' ', '&nbsp;', $boxes[$i]['formatted']);
                            echo "<OPTION VALUE=\"$box\">$box2</option>";
@@ -368,7 +415,7 @@ if (!DB::isError($res)) {
                <select name=ignore_rem>
                   <?php
                      for ($i = 0; $i < count($GLOBALS['bayesspam_ignore_folders']); $i++) {
-                        if ($GLOBALS['bayesspam_ignore_folders'][$i] != 'INBOX.Trash' && $GLOBALS['bayesspam_ignore_folders'][$i] != $GLOBALS['bayesspam_folder']) {
+                        if ($GLOBALS['bayesspam_ignore_folders'][$i] != $GLOBALS['trash_folder'] && $GLOBALS['bayesspam_ignore_folders'][$i] != $GLOBALS['bayesspam_folder']) {
                            $box = $GLOBALS['bayesspam_ignore_folders'][$i];
                            $box2 = str_replace(' ', '&nbsp;', $GLOBALS['bayesspam_ignore_folders'][$i]);
                            echo "<OPTION VALUE=\"$box\">$box2</option>";
@@ -386,7 +433,7 @@ if (!DB::isError($res)) {
    <?php } ?>
    <tr>
       <td align=center colspan=2>
-         &nbsp;<P>
+         &nbsp;<p>
          <b><?php echo _("Spam Database Stats"); ?>:</b><br>
          <table>
             <?php if ($GLOBALS['bayesspam_filtering_enabled']) { ?>
@@ -590,16 +637,16 @@ if (!DB::isError($res)) {
          </td>
       </tr>
    <?php } ?>
-</table><P>
-To start using BayesSpam Intelligent Filtering, you must first build up a database of what you consider to be spam, and what you consider to not be spam. 
-To do this, enable the links. When you read an email, there will be two new links to the upper right, to let you mark the mail as Spam or NonSpam. 
-Use them a few dozen times on both spam and nonspam emails before going any further. The more times you use them, the more accurate your filtering will become.
-<P>Once you have a few dozen emails in your database (Come here to check your DB stats) you can enable the filtering itself.<P>
+</table><p>
+<?php print _("To start using BayesSpam Intelligent Filtering, you must first build up a database of what you consider to be spam, and what you consider to not be spam.") . ' ';
+print _("To do this, enable the links. When you read an email, there will be two new links to the upper right, to let you mark the mail as Spam or NonSpam.") . ' ';
+print _("Use them a few dozen times on both spam and nonspam emails before going any further. The more times you use them, the more accurate your filtering will become.");
+print '<p>' . _("Once you have a few dozen emails in your database (Come here to check your DB stats) you can enable the filtering itself.") . '<p>';
 
-<b>Spam Deletion</b>: This option is somewhat dangerous, since if you get a false positive, it would delete the message without ever telling you. False positives /shouldn't/ happen, but you use this option at your own risk. This option requires Filtering to be turned on as well.<P>
-<b>Ignore List</b>: Folders to not run the filtering on. This is not 100% reliable, since BayesSpam may load before the main Filters plugin, thus giving it a chance to run on the messages in the inbox before they've been moved to their own folders.<P>
+print '<b>' . _("Spam Deletion") . '</b>: ' . _("This option is somewhat dangerous, since if you get a false positive, it would delete the message without ever telling you. False positives should not happen, but you use this option at your own risk. This option requires Filtering to be turned on as well.") . '<p>';
+print '<b>' . _("Ignore List") . '</b>: ' . _("Folders to not run the filtering on. This is not 100% reliable, since BayesSpam may load before the main Filters plugin, thus giving it a chance to run on the messages in the inbox before they've been moved to their own folders.") . '<p>';
 
-<?php if ($GLOBALS['bayes_allow_db_nuke']) { ?>
-   <b>Empty Database</b>: Do this if you for some reason want to wipe out your current spam DB and start all over.<P>
-<?php } ?>
+if ($GLOBALS['bayes_allow_db_nuke']) {
+print '<b>' . _("Empty Database") . '</b>: ' . _("Do this if you for some reason want to wipe out your current spam DB and start all over.") . '<p>';
+} ?>
 </body></html>
